@@ -19,9 +19,7 @@ class ChangeCollector(object):
         if not self.changes:
             return None
 
-        def compare_changes(change1, change2):
-            return cmp(change1[:2], change2[:2])
-        self.changes.sort(compare_changes)
+        self.changes.sort(key=lambda x: x[:2])
         pieces = []
         last_changed = 0
         for change in self.changes:
@@ -131,31 +129,31 @@ class _CustomGenerator(object):
                 i += 1
         return result
 
-    _main_chars = re.compile(r'[\'|"|#|\\|\[|\]|\{|\}|\(|\)]')
+    # Matches all backslashes before the token, to detect escaped quotes
+    _main_tokens = re.compile(r'(\\*)((\'\'\'|"""|\'|")|#|\[|\]|\{|\}|\(|\))')
 
     def _analyze_line(self, line):
-        char = None
-        for match in self._main_chars.finditer(line):
-            char = match.group()
-            i = match.start()
-            if char in '\'"':
+        token = None
+        for match in self._main_tokens.finditer(line):
+            prefix = match.group(1)
+            token = match.group(2)
+            # Skip any tokens which are escaped
+            if len(prefix) % 2 == 1:
+                continue
+            if token in ["'''", '"""', "'", '"']:
                 if not self.in_string:
-                    self.in_string = char
-                    if char * 3 == line[i:i + 3]:
-                        self.in_string = char * 3
-                elif self.in_string == line[i:i + len(self.in_string)] and \
-                    not (i > 0 and line[i - 1] == '\\' and
-                         not (i > 1 and line[i - 2] == '\\')):
+                    self.in_string = token
+                elif self.in_string == token:
                     self.in_string = ''
             if self.in_string:
                 continue
-            if char == '#':
+            if token == '#':
                 break
-            if char in '([{':
+            if token in '([{':
                 self.open_count += 1
-            elif char in ')]}':
+            elif token in ')]}':
                 self.open_count -= 1
-        if line and char != '#' and line.endswith('\\'):
+        if line and token != '#' and line.endswith('\\'):
             self.continuation = True
         else:
             self.continuation = False
@@ -177,7 +175,7 @@ class LogicalLineFinder(object):
             block_start = get_block_start(self.lines, line_number, indents)
             try:
                 return self._block_logical_line(block_start, line_number)
-            except IndentationError, e:
+            except IndentationError as e:
                 tries += 1
                 if tries == 5:
                     raise e
@@ -222,7 +220,7 @@ class LogicalLineFinder(object):
                 if line_number <= end:
                     return (start, end)
                 last_end = end + 1
-        except tokenize.TokenError, e:
+        except tokenize.TokenError as e:
             current = e.args[1][0]
             return (last_end, max(last_end, current - 1))
         return (last_end, None)
@@ -352,13 +350,22 @@ def count_line_indents(line):
     return 0
 
 
-def get_string_pattern():
-    start = r'(\b[uU]?[rR]?)?'
-    longstr = r'%s"""(\\.|"(?!"")|\\\n|[^"\\])*"""' % start
-    shortstr = r'%s"(\\.|[^"\\\n])*"' % start
+def get_string_pattern_with_prefix(prefix):
+    longstr = r'%s"""(\\.|"(?!"")|\\\n|[^"\\])*"""' % prefix
+    shortstr = r'%s"(\\.|\\\n|[^"\\\n])*"' % prefix
     return '|'.join([longstr, longstr.replace('"', "'"),
                      shortstr, shortstr.replace('"', "'")])
 
 
+def get_string_pattern():
+    prefix = r'(?<![fF])(\b[uUbB]?[rR]?)?'
+    return get_string_pattern_with_prefix(prefix)
+
+
+def get_formatted_string_pattern():
+    prefix = r'(\b[rR]?[fF]|[fF][rR]?)'
+    return get_string_pattern_with_prefix(prefix)
+
+
 def get_comment_pattern():
     return r'#[^\n]*'
