@@ -25,14 +25,14 @@ class ChangeStackTest(unittest.TestCase):
         myfile.write('1')
         stack = rope.contrib.changestack.ChangeStack(self.project)
         stack.push(rope.base.change.ChangeContents(myfile, '2'))
-        self.assertEquals('2', myfile.read())
+        self.assertEqual('2', myfile.read())
         stack.push(rope.base.change.ChangeContents(myfile, '3'))
-        self.assertEquals('3', myfile.read())
+        self.assertEqual('3', myfile.read())
         stack.pop_all()
-        self.assertEquals('1', myfile.read())
+        self.assertEqual('1', myfile.read())
         changes = stack.merged()
         self.project.do(changes)
-        self.assertEquals('3', myfile.read())
+        self.assertEqual('3', myfile.read())
 
 
 if __name__ == '__main__':
