@@ -14,6 +14,8 @@ try:
 except NameError:
     basestring = (str, bytes)
 
+NameConstant = 'Name' if sys.version_info <= (3, 8) else 'NameConstant'
+Bytes = 'Bytes' if (3, 0) <= sys.version_info <= (3, 8) else 'Str'
 
 class PatchedASTTest(unittest.TestCase):
 
@@ -23,6 +25,15 @@ class PatchedASTTest(unittest.TestCase):
     def tearDown(self):
         super(PatchedASTTest, self).tearDown()
 
+    def test_bytes_string(self):
+        source = '1 + b"("\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        str_fragment = 'b"("'
+        start = source.index(str_fragment)
+        checker.check_region(Bytes, start, start + len(str_fragment))
+        checker.check_children(Bytes, [str_fragment])
+
     def test_integer_literals_and_region(self):
         source = 'a = 10\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -85,6 +96,13 @@ class PatchedASTTest(unittest.TestCase):
         # start = source.index('10')
         checker.check_children('Num', ['10'])
 
+    def test_ellipsis(self):
+        source = 'a[...]\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('...')
+        checker.check_region('Ellipsis', start, start + len('...'))
+
     def test_ass_name_node(self):
         source = 'a = 10\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -124,7 +142,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('BoolOp', 0, len(source) - 1)
         checker.check_children(
-            'BoolOp', ['Name', ' ', 'and', ' ', 'Name'])
+            'BoolOp', [NameConstant, ' ', 'and', ' ', NameConstant])
 
     def test_basic_closing_parens(self):
         source = '1 + (2)\n'
@@ -263,7 +281,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('Assert', 0, len(source) - 1)
         checker.check_children(
-            'Assert', ['assert', ' ', 'Name'])
+            'Assert', ['assert', ' ', NameConstant])
 
     def test_assert2(self):
         source = 'assert True, "error"\n'
@@ -271,7 +289,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('Assert', 0, len(source) - 1)
         checker.check_children(
-            'Assert', ['assert', ' ', 'Name', '', ',', ' ', 'Str'])
+            'Assert', ['assert', ' ', NameConstant, '', ',', ' ', 'Str'])
 
     def test_aug_assign_node(self):
         source = 'a += 1\n'
@@ -340,7 +358,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'Call', ['Name', '', '(', '', 'Num', '', ',',
                 ' *', 'Starred', '', ')'])
- 
+
     @testutils.only_for_versions_lower('3.5')
     def test_call_func_and_only_dstar_args(self):
         source = 'f(**kwds)\n'
@@ -594,7 +612,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('If', 0, len(source) - 1)
         checker.check_children(
-            'If', ['if', ' ', 'Name', '', ':', '\n    ', 'Pass', '\n',
+            'If', ['if', ' ', NameConstant, '', ':', '\n    ', 'Pass', '\n',
                    'else', '', ':', '\n    ', 'Pass'])
 
     def test_if_node2(self):
@@ -603,7 +621,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('If', 0, len(source) - 1)
         checker.check_children(
-            'If', ['if', ' ', 'Name', '', ':', '\n    ', 'Pass', '\n',
+            'If', ['if', ' ', NameConstant, '', ':', '\n    ', 'Pass', '\n',
                    'If'])
 
     def test_if_node3(self):
@@ -613,7 +631,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('If', 0, len(source) - 1)
         checker.check_children(
-            'If', ['if', ' ', 'Name', '', ':', '\n    ', 'Pass', '\n',
+            'If', ['if', ' ', NameConstant, '', ':', '\n    ', 'Pass', '\n',
                    'else', '', ':', '\n    ', 'If'])
 
     def test_import_node(self):
@@ -630,7 +648,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_region('Lambda', 0, len(source) - 1)
         checker.check_children(
-            'Lambda', ['lambda', ' ', 'arguments', '', ':', ' ', 'Name'])
+            'Lambda', ['lambda', ' ', 'arguments', '', ':', ' ', NameConstant])
         expected_child = pycompat.ast_arg_type.__name__
         checker.check_children(
             'arguments', [expected_child, '', ',', ' ',
@@ -654,7 +672,7 @@ class PatchedASTTest(unittest.TestCase):
             'ListComp', ['[', '', 'Name', ' ', 'comprehension', '', ']'])
         checker.check_children(
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
-                              'Call', ' ', 'if', ' ', 'Name'])
+                              'Call', ' ', 'if', ' ', NameConstant])
 
     def test_list_comp_node_with_multiple_comprehensions(self):
         source = '[i for i in range(1) for j in range(1) if True]\n'
@@ -666,7 +684,7 @@ class PatchedASTTest(unittest.TestCase):
                          ' ', 'comprehension', '', ']'])
         checker.check_children(
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
-                              'Call', ' ', 'if', ' ', 'Name'])
+                              'Call', ' ', 'if', ' ', NameConstant])
 
     def test_set_node(self):
         # make sure we are in a python version with set literals
@@ -699,7 +717,7 @@ class PatchedASTTest(unittest.TestCase):
             'SetComp', ['{', '', 'Name', ' ', 'comprehension', '', '}'])
         checker.check_children(
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
-                              'Call', ' ', 'if', ' ', 'Name'])
+                              'Call', ' ', 'if', ' ', NameConstant])
 
     def test_dict_comp_node(self):
         # make sure we are in a python version with dict comprehensions
@@ -718,7 +736,7 @@ class PatchedASTTest(unittest.TestCase):
                          ' ', 'comprehension', '', '}'])
         checker.check_children(
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
-                              'Call', ' ', 'if', ' ', 'Name'])
+                              'Call', ' ', 'if', ' ', NameConstant])
 
     def test_ext_slice_node(self):
         source = 'x = xs[0,:]\n'
@@ -747,7 +765,7 @@ class PatchedASTTest(unittest.TestCase):
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
         checker.check_children('Expr', ['BoolOp'])
-        checker.check_children('BoolOp', ['UnaryOp', ' ', 'or', ' ', 'Name'])
+        checker.check_children('BoolOp', ['UnaryOp', ' ', 'or', ' ', NameConstant])
 
     @testutils.only_for_versions_lower('3')
     def test_print_node(self):
@@ -790,7 +808,7 @@ class PatchedASTTest(unittest.TestCase):
         source = 'def f():\n    return None\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        checker.check_children('Return', ['return', ' ', 'Name'])
+        checker.check_children('Return', ['return', ' ', NameConstant])
 
     def test_empty_return_node(self):
         source = 'def f():\n    return\n'
@@ -852,14 +870,14 @@ class PatchedASTTest(unittest.TestCase):
         source = 'def f():\n    yield None\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        checker.check_children('Yield', ['yield', ' ', 'Name'])
+        checker.check_children('Yield', ['yield', ' ', NameConstant])
 
     def test_while_node(self):
         source = 'while True:\n    pass\nelse:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
         checker.check_children(
-            'While', ['while', ' ', 'Name', '', ':', '\n    ', 'Pass', '\n',
+            'While', ['while', ' ', NameConstant, '', ':', '\n    ', 'Pass', '\n',
                       'else', '', ':', '\n    ', 'Pass'])
 
     @testutils.only_for('2.5')
@@ -973,7 +991,7 @@ class PatchedASTTest(unittest.TestCase):
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
         checker.check_children(
-            'IfExp', ['Num', ' ', 'if', ' ', 'Name', ' ', 'else',
+            'IfExp', ['Num', ' ', 'if', ' ', NameConstant, ' ', 'else',
                       ' ', 'Num'])
 
     def test_delete_node(self):
@@ -1048,7 +1066,7 @@ class _ResultChecker(object):
         node = self._find_node(text)
         if node is None:
             self.test_case.fail('Node <%s> cannot be found' % text)
-        self.test_case.assertEquals((start, end), node.region)
+        self.test_case.assertEqual((start, end), node.region)
 
     def _find_node(self, text):
         goal = text
@@ -1060,6 +1078,8 @@ class _ResultChecker(object):
 
             def __call__(self, node):
                 for text in goal:
+                    if sys.version_info >= (3, 8) and text in ['Num', 'Str', 'NameConstant', 'Ellipsis']:
+                        text = 'Constant'
                     if str(node).startswith(text):
                         self.result = node
                         break
@@ -1076,18 +1096,20 @@ class _ResultChecker(object):
         if node is None:
             self.test_case.fail('Node <%s> cannot be found' % text)
         result = list(node.sorted_children)
-        self.test_case.assertEquals(len(children), len(result))
+        self.test_case.assertEqual(len(children), len(result))
         for expected, child in zip(children, result):
             goals = expected
             if not isinstance(expected, (tuple, list)):
                 goals = [expected]
             for goal in goals:
                 if goal == '' or isinstance(child, basestring):
-                    self.test_case.assertEquals(goal, child)
+                    self.test_case.assertEqual(goal, child)
                     break
             else:
-                self.test_case.assertNotEquals(
+                self.test_case.assertNotEqual(
                     '', text, 'probably ignoring some node')
+                if sys.version_info >= (3, 8) and expected in ['Num', 'Str', 'NameConstant', 'Ellipsis']:
+                    expected = 'Constant'
                 self.test_case.assertTrue(
                     child.__class__.__name__.startswith(expected),
                     msg='Expected <%s> but was <%s>' %
