@@ -36,62 +36,62 @@ class RenameRefactoringTest(unittest.TestCase):
 
     def test_simple_global_variable_renaming(self):
         refactored = self._local_rename('a_var = 20\n', 2, 'new_var')
-        self.assertEquals('new_var = 20\n', refactored)
+        self.assertEqual('new_var = 20\n', refactored)
 
     def test_variable_renaming_only_in_its_scope(self):
         refactored = self._local_rename(
             'a_var = 20\ndef a_func():\n    a_var = 10\n', 32, 'new_var')
-        self.assertEquals('a_var = 20\ndef a_func():\n    new_var = 10\n',
+        self.assertEqual('a_var = 20\ndef a_func():\n    new_var = 10\n',
                           refactored)
 
     def test_not_renaming_dot_name(self):
         refactored = self._local_rename(
             "replace = True\n'aaa'.replace('a', 'b')\n", 1, 'new_var')
-        self.assertEquals("new_var = True\n'aaa'.replace('a', 'b')\n",
+        self.assertEqual("new_var = True\n'aaa'.replace('a', 'b')\n",
                           refactored)
 
     def test_renaming_multiple_names_in_the_same_line(self):
         refactored = self._local_rename(
             'a_var = 10\na_var = 10 + a_var / 2\n', 2, 'new_var')
-        self.assertEquals('new_var = 10\nnew_var = 10 + new_var / 2\n',
+        self.assertEqual('new_var = 10\nnew_var = 10 + new_var / 2\n',
                           refactored)
 
     def test_renaming_names_when_getting_some_attribute(self):
         refactored = self._local_rename(
             "a_var = 'a b c'\na_var.split('\\n')\n", 2, 'new_var')
-        self.assertEquals("new_var = 'a b c'\nnew_var.split('\\n')\n",
+        self.assertEqual("new_var = 'a b c'\nnew_var.split('\\n')\n",
                           refactored)
 
     def test_renaming_names_when_getting_some_attribute2(self):
         refactored = self._local_rename(
             "a_var = 'a b c'\na_var.split('\\n')\n", 20, 'new_var')
-        self.assertEquals("new_var = 'a b c'\nnew_var.split('\\n')\n",
+        self.assertEqual("new_var = 'a b c'\nnew_var.split('\\n')\n",
                           refactored)
 
     def test_renaming_function_parameters1(self):
         refactored = self._local_rename(
             "def f(a_param):\n    print(a_param)\n", 8, 'new_param')
-        self.assertEquals("def f(new_param):\n    print(new_param)\n",
+        self.assertEqual("def f(new_param):\n    print(new_param)\n",
                           refactored)
 
     def test_renaming_function_parameters2(self):
         refactored = self._local_rename(
             "def f(a_param):\n    print(a_param)\n", 30, 'new_param')
-        self.assertEquals("def f(new_param):\n    print(new_param)\n",
+        self.assertEqual("def f(new_param):\n    print(new_param)\n",
                           refactored)
 
     def test_renaming_occurrences_inside_functions(self):
         code = 'def a_func(p1):\n    a = p1\na_func(1)\n'
         refactored = self._local_rename(code, code.index('p1') + 1,
                                         'new_param')
-        self.assertEquals(
+        self.assertEqual(
             'def a_func(new_param):\n    a = new_param\na_func(1)\n',
             refactored)
 
     def test_renaming_arguments_for_normal_args_changing_calls(self):
         code = 'def a_func(p1=None, p2=None):\n    pass\na_func(p2=1)\n'
         refactored = self._local_rename(code, code.index('p2') + 1, 'p3')
-        self.assertEquals(
+        self.assertEqual(
             'def a_func(p1=None, p3=None):\n    pass\na_func(p3=1)\n',
             refactored)
 
@@ -104,76 +104,113 @@ class RenameRefactoringTest(unittest.TestCase):
         expected = 'class A(object):\n    ' \
             'def __init__(self, new_param):\n        pass\n' \
             'a_var = A(new_param=1)\n'
-        self.assertEquals(expected, refactored)
+        self.assertEqual(expected, refactored)
 
-    def test_renam_functions_parameters_and_occurances_in_other_modules(self):
+    def test_rename_functions_parameters_and_occurences_in_other_modules(self):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod2 = testutils.create_module(self.project, 'mod2')
         mod1.write('def a_func(a_param):\n    print(a_param)\n')
         mod2.write('from mod1 import a_func\na_func(a_param=10)\n')
         self._rename(mod1, mod1.read().index('a_param') + 1, 'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n',
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n',
                           mod1.read())
-        self.assertEquals('from mod1 import a_func\na_func(new_param=10)\n',
+        self.assertEqual('from mod1 import a_func\na_func(new_param=10)\n',
                           mod2.read())
 
     def test_renaming_with_backslash_continued_names(self):
         refactored = self._local_rename(
             "replace = True\n'ali'.\\\nreplace\n", 2, 'is_replace')
-        self.assertEquals("is_replace = True\n'ali'.\\\nreplace\n",
+        self.assertEqual("is_replace = True\n'ali'.\\\nreplace\n",
+                          refactored)
+
+    @testutils.only_for('3.6')
+    def test_renaming_occurrence_in_f_string(self):
+        refactored = self._local_rename(
+            "a_var = 20\na_string=f'value: {a_var}'\n", 2, 'new_var')
+        self.assertEqual("new_var = 20\na_string=f'value: {new_var}'\n",
+                          refactored)
+
+    @testutils.only_for('3.6')
+    def test_renaming_occurrence_in_nested_f_string(self):
+        refactored = self._local_rename(
+            "a_var = 20\na_string=f'{f\"{a_var}\"}'\n", 2, 'new_var')
+        self.assertEqual(
+            "new_var = 20\na_string=f'{f\"{new_var}\"}'\n",
+            refactored)
+
+    @testutils.only_for('3.6')
+    def test_not_renaming_string_contents_in_f_string(self):
+        refactored = self._local_rename(
+            "a_var = 20\na_string=f'{\"a_var\"}'\n", 2, 'new_var')
+        self.assertEqual("new_var = 20\na_string=f'{\"a_var\"}'\n",
                           refactored)
 
     def test_not_renaming_string_contents(self):
         refactored = self._local_rename("a_var = 20\na_string='a_var'\n",
                                         2, 'new_var')
-        self.assertEquals("new_var = 20\na_string='a_var'\n",
+        self.assertEqual("new_var = 20\na_string='a_var'\n",
                           refactored)
 
     def test_not_renaming_comment_contents(self):
         refactored = self._local_rename("a_var = 20\n# a_var\n",
                                         2, 'new_var')
-        self.assertEquals("new_var = 20\n# a_var\n", refactored)
+        self.assertEqual("new_var = 20\n# a_var\n", refactored)
 
     def test_renaming_all_occurances_in_containing_scope(self):
         code = 'if True:\n    a_var = 1\nelse:\n    a_var = 20\n'
         refactored = self._local_rename(code, 16, 'new_var')
-        self.assertEquals(
+        self.assertEqual(
             'if True:\n    new_var = 1\nelse:\n    new_var = 20\n', refactored)
 
     def test_renaming_a_variable_with_arguement_name(self):
         code = 'a_var = 10\ndef a_func(a_var):\n    print(a_var)\n'
         refactored = self._local_rename(code, 1, 'new_var')
-        self.assertEquals(
+        self.assertEqual(
             'new_var = 10\ndef a_func(a_var):\n    print(a_var)\n', refactored)
 
     def test_renaming_an_arguement_with_variable_name(self):
         code = 'a_var = 10\ndef a_func(a_var):\n    print(a_var)\n'
         refactored = self._local_rename(code, len(code) - 3, 'new_var')
-        self.assertEquals(
+        self.assertEqual(
             'a_var = 10\ndef a_func(new_var):\n    print(new_var)\n',
             refactored)
 
     def test_renaming_function_with_local_variable_name(self):
         code = 'def a_func():\n    a_func=20\na_func()'
         refactored = self._local_rename(code, len(code) - 3, 'new_func')
-        self.assertEquals('def new_func():\n    a_func=20\nnew_func()',
+        self.assertEqual('def new_func():\n    a_func=20\nnew_func()',
                           refactored)
 
     def test_renaming_functions(self):
         code = 'def a_func():\n    pass\na_func()\n'
         refactored = self._local_rename(code, len(code) - 5, 'new_func')
-        self.assertEquals('def new_func():\n    pass\nnew_func()\n',
+        self.assertEqual('def new_func():\n    pass\nnew_func()\n',
                           refactored)
 
+    @testutils.only_for('3.5')
+    def test_renaming_async_function(self):
+        code = 'async def a_func():\n    pass\na_func()'
+        refactored = self._local_rename(code, len(code) - 5, 'new_func')
+        self.assertEqual('async def new_func():\n    pass\nnew_func()',
+                          refactored)
+
+    @testutils.only_for('3.5')
+    def test_renaming_await(self):
+        code = 'async def b_func():\n    pass\nasync def a_func():\n    await b_func()'
+        refactored = self._local_rename(code, len(code) - 5, 'new_func')
+        self.assertEqual('async def new_func():\n    pass\nasync def a_func():\n    await new_func()',
+                          refactored)
+
+
     def test_renaming_functions_across_modules(self):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write('def a_func():\n    pass\na_func()\n')
         mod2 = testutils.create_module(self.project, 'mod2')
         mod2.write('import mod1\nmod1.a_func()\n')
         self._rename(mod1, len(mod1.read()) - 5, 'new_func')
-        self.assertEquals('def new_func():\n    pass\nnew_func()\n',
+        self.assertEqual('def new_func():\n    pass\nnew_func()\n',
                           mod1.read())
-        self.assertEquals('import mod1\nmod1.new_func()\n', mod2.read())
+        self.assertEqual('import mod1\nmod1.new_func()\n', mod2.read())
 
     def test_renaming_functions_across_modules_from_import(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -181,9 +218,9 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2')
         mod2.write('from mod1 import a_func\na_func()\n')
         self._rename(mod1, len(mod1.read()) - 5, 'new_func')
-        self.assertEquals('def new_func():\n    pass\nnew_func()\n',
+        self.assertEqual('def new_func():\n    pass\nnew_func()\n',
                           mod1.read())
-        self.assertEquals('from mod1 import new_func\nnew_func()\n',
+        self.assertEqual('from mod1 import new_func\nnew_func()\n',
                           mod2.read())
 
     def test_renaming_functions_from_another_module(self):
@@ -192,9 +229,9 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2')
         mod2.write('import mod1\nmod1.a_func()\n')
         self._rename(mod2, len(mod2.read()) - 5, 'new_func')
-        self.assertEquals('def new_func():\n    pass\nnew_func()\n',
+        self.assertEqual('def new_func():\n    pass\nnew_func()\n',
                           mod1.read())
-        self.assertEquals('import mod1\nmod1.new_func()\n', mod2.read())
+        self.assertEqual('import mod1\nmod1.new_func()\n', mod2.read())
 
     def test_applying_all_changes_together(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -202,8 +239,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2')
         mod2.write('def a_func():\n    pass\na_func()\n')
         self._rename(mod2, len(mod2.read()) - 5, 'new_func')
-        self.assertEquals('import mod2\nmod2.new_func()\n', mod1.read())
-        self.assertEquals('def new_func():\n    pass\nnew_func()\n',
+        self.assertEqual('import mod2\nmod2.new_func()\n', mod1.read())
+        self.assertEqual('def new_func():\n    pass\nnew_func()\n',
                           mod2.read())
 
     def test_renaming_modules(self):
@@ -214,7 +251,17 @@ class RenameRefactoringTest(unittest.TestCase):
         self._rename(mod2, mod2.read().index('mod1') + 1, 'newmod')
         self.assertTrue(not mod1.exists() and
                         self.project.find_module('newmod') is not None)
-        self.assertEquals('from newmod import a_func\n', mod2.read())
+        self.assertEqual('from newmod import a_func\n', mod2.read())
+
+    def test_renaming_modules_aliased(self):
+        mod1 = testutils.create_module(self.project, 'mod1')
+        mod1.write('def a_func():\n    pass\n')
+        mod2 = testutils.create_module(self.project, 'mod2')
+        mod2.write('import mod1 as m\nm.a_func()\n')
+        self._rename(mod1, None, 'newmod')
+        self.assertTrue(not mod1.exists() and
+                        self.project.find_module('newmod') is not None)
+        self.assertEqual('import newmod as m\nm.a_func()\n', mod2.read())
 
     def test_renaming_packages(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -225,7 +272,7 @@ class RenameRefactoringTest(unittest.TestCase):
         self._rename(mod2, 6, 'newpkg')
         self.assertTrue(self.project.find_module('newpkg.mod1') is not None)
         new_mod2 = self.project.find_module('newpkg.mod2')
-        self.assertEquals('from newpkg.mod1 import a_func\n', new_mod2.read())
+        self.assertEqual('from newpkg.mod1 import a_func\n', new_mod2.read())
 
     def test_module_dependencies(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -236,8 +283,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write('def AClass():\n    return 0\n')
 
         self._rename(mod2, len(mod2.read()) - 3, 'a_func')
-        self.assertEquals('def a_func():\n    return 0\n', mod1.read())
-        self.assertEquals('import mod1\na_var = mod1.a_func()\n', mod2.read())
+        self.assertEqual('def a_func():\n    return 0\n', mod1.read())
+        self.assertEqual('import mod1\na_var = mod1.a_func()\n', mod2.read())
 
     def test_renaming_class_attributes(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -248,9 +295,9 @@ class RenameRefactoringTest(unittest.TestCase):
                    'another_var = a_var.an_attr')
 
         self._rename(mod1, mod1.read().index('an_attr'), 'attr')
-        self.assertEquals('class AClass(object):\n    def __init__(self):\n'
+        self.assertEqual('class AClass(object):\n    def __init__(self):\n'
                           '        self.attr = 10\n', mod1.read())
-        self.assertEquals(
+        self.assertEqual(
             'import mod1\na_var = mod1.AClass()\nanother_var = a_var.attr',
             mod2.read())
 
@@ -263,10 +310,10 @@ class RenameRefactoringTest(unittest.TestCase):
                    'another_var = a_var.an_attr')
 
         self._rename(mod1, mod1.read().rindex('an_attr'), 'attr')
-        self.assertEquals(
+        self.assertEqual(
             'class AClass(object):\n    def __init__(self):\n'
             '        an_attr = 10\n        self.attr = 10\n', mod1.read())
-        self.assertEquals(
+        self.assertEqual(
             'import mod1\na_var = mod1.AClass()\nanother_var = a_var.attr',
             mod2.read())
 
@@ -277,7 +324,7 @@ class RenameRefactoringTest(unittest.TestCase):
 
         self._rename(mod, mod.read().rindex('a_method') + 1, 'new_method',
                      in_hierarchy=True)
-        self.assertEquals(
+        self.assertEqual(
             'class A(object):\n    def new_method(self):\n        pass\n'
             'class B(A):\n    def new_method(self):\n        pass\n',
             mod.read())
@@ -290,7 +337,7 @@ class RenameRefactoringTest(unittest.TestCase):
 
         self._rename(mod, mod.read().rindex('a_method') + 1, 'new_method',
                      in_hierarchy=True)
-        self.assertEquals(
+        self.assertEqual(
             'class A(object):\n    def new_method(self):\n        pass\n'
             'class B(A):\n    def new_method(self):\n        pass\n'
             'class C(A):\n    def new_method(self):\n        pass\n',
@@ -303,7 +350,7 @@ class RenameRefactoringTest(unittest.TestCase):
 
         self._rename(mod, mod.read().rindex('a_method') + 1, 'new_method',
                      in_hierarchy=False)
-        self.assertEquals(
+        self.assertEqual(
             'class A(object):\n    def a_method(self):\n        pass\n'
             'class B(A):\n    def new_method(self):\n        pass\n',
             mod.read())
@@ -313,7 +360,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write('def a_func():\n    pass\na_func()\n')
         self._rename(mod1, len(mod1.read()) - 5, 'new_func')
         self.project.history.undo()
-        self.assertEquals('def a_func():\n    pass\na_func()\n', mod1.read())
+        self.assertEqual('def a_func():\n    pass\na_func()\n', mod1.read())
 
     def test_undoing_renaming_modules(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -322,8 +369,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2.write('from mod1 import a_func\n')
         self._rename(mod2, 6, 'newmod')
         self.project.history.undo()
-        self.assertEquals('mod1.py', mod1.path)
-        self.assertEquals('from mod1 import a_func\n', mod2.read())
+        self.assertEqual('mod1.py', mod1.path)
+        self.assertEqual('from mod1 import a_func\n', mod2.read())
 
     def test_rename_in_module_renaming_one_letter_names_for_expressions(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -334,25 +381,48 @@ class RenameRefactoringTest(unittest.TestCase):
             self.project, 'a', old_pyname)
         refactored = rename.rename_in_module(
             finder, 'new_var', pymodule=pymod, replace_primary=True)
-        self.assertEquals('new_var = 10\nprint(1+new_var)\n', refactored)
+        self.assertEqual('new_var = 10\nprint(1+new_var)\n', refactored)
 
     def test_renaming_for_loop_variable(self):
         code = 'for var in range(10):\n    print(var)\n'
         refactored = self._local_rename(code, code.find('var') + 1, 'new_var')
-        self.assertEquals('for new_var in range(10):\n    print(new_var)\n',
+        self.assertEqual('for new_var in range(10):\n    print(new_var)\n',
+                          refactored)
+
+    @testutils.only_for('3.5')
+    def test_renaming_async_for_loop_variable(self):
+        code = 'async def func():\n    async for var in range(10):\n        print(var)\n'
+        refactored = self._local_rename(code, code.find('var') + 1, 'new_var')
+        self.assertEqual('async def func():\n    async for new_var in range(10):\n        print(new_var)\n',
+                          refactored)
+
+    @testutils.only_for('3.5')
+    def test_renaming_async_with_context_manager(self):
+        code = 'def a_cm(): pass\n'\
+               'async def a_func():\n    async with a_cm() as x: pass'
+        refactored = self._local_rename(code, code.find('a_cm') + 1, 'another_cm')
+        expected = 'def another_cm(): pass\n'\
+                   'async def a_func():\n    async with another_cm() as x: pass'
+        self.assertEqual(refactored, expected)
+
+    @testutils.only_for('3.5')
+    def test_renaming_async_with_as_variable(self):
+        code = 'async def func():\n    async with a_func() as var:\n        print(var)\n'
+        refactored = self._local_rename(code, code.find('var') + 1, 'new_var')
+        self.assertEqual('async def func():\n    async with a_func() as new_var:\n        print(new_var)\n',
                           refactored)
 
     def test_renaming_parameters(self):
         code = 'def a_func(param):\n    print(param)\na_func(param=hey)\n'
         refactored = self._local_rename(code, code.find('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'a_func(new_param=hey)\n', refactored)
 
     def test_renaming_assigned_parameters(self):
         code = 'def f(p):\n    p = p + 1\n    return p\nf(p=1)\n'
         refactored = self._local_rename(code, code.find('p'), 'arg')
-        self.assertEquals('def f(arg):\n    arg = arg + 1\n'
+        self.assertEqual('def f(arg):\n    arg = arg + 1\n'
                           '    return arg\nf(arg=1)\n', refactored)
 
     def test_renaming_parameters_not_renaming_others(self):
@@ -360,7 +430,7 @@ class RenameRefactoringTest(unittest.TestCase):
             '\n    print(param)\nparam=10\na_func(param)\n'
         refactored = self._local_rename(code, code.find('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'param=10\na_func(param)\n', refactored)
 
     def test_renaming_parameters_not_renaming_others2(self):
@@ -368,7 +438,7 @@ class RenameRefactoringTest(unittest.TestCase):
             'param=10\na_func(param=param)'
         refactored = self._local_rename(code, code.find('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'param=10\na_func(new_param=param)', refactored)
 
     def test_renaming_parameters_with_multiple_params(self):
@@ -376,7 +446,7 @@ class RenameRefactoringTest(unittest.TestCase):
                'a_func(param1=1, param2=2)\n'
         refactored = self._local_rename(code, code.find('param1') + 1,
                                         'new_param')
-        self.assertEquals(
+        self.assertEqual(
             'def a_func(new_param, param2):\n    print(new_param)\n'
             'a_func(new_param=1, param2=2)\n', refactored)
 
@@ -385,28 +455,28 @@ class RenameRefactoringTest(unittest.TestCase):
                'a_func(param1=1, param2=2)\n'
         refactored = self._local_rename(code, code.rfind('param2') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(param1, new_param):\n    print(param1)\n'
+        self.assertEqual('def a_func(param1, new_param):\n    print(param1)\n'
                           'a_func(param1=1, new_param=2)\n', refactored)
 
     def test_renaming_parameters_on_calls(self):
         code = 'def a_func(param):\n    print(param)\na_func(param = hey)\n'
         refactored = self._local_rename(code, code.rfind('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'a_func(new_param = hey)\n', refactored)
 
     def test_renaming_parameters_spaces_before_call(self):
         code = 'def a_func(param):\n    print(param)\na_func  (param=hey)\n'
         refactored = self._local_rename(code, code.rfind('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'a_func  (new_param=hey)\n', refactored)
 
     def test_renaming_parameter_like_objects_after_keywords(self):
         code = 'def a_func(param):\n    print(param)\ndict(param=hey)\n'
         refactored = self._local_rename(code, code.find('param') + 1,
                                         'new_param')
-        self.assertEquals('def a_func(new_param):\n    print(new_param)\n'
+        self.assertEqual('def a_func(new_param):\n    print(new_param)\n'
                           'dict(param=hey)\n', refactored)
 
     def test_renaming_variables_in_init_dot_pys(self):
@@ -416,8 +486,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('import pkg\nprint(pkg.a_var)\n')
         self._rename(mod, mod.read().index('a_var') + 1, 'new_var')
-        self.assertEquals('new_var = 10\n', init_dot_py.read())
-        self.assertEquals('import pkg\nprint(pkg.new_var)\n', mod.read())
+        self.assertEqual('new_var = 10\n', init_dot_py.read())
+        self.assertEqual('import pkg\nprint(pkg.new_var)\n', mod.read())
 
     def test_renaming_variables_in_init_dot_pys2(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -427,8 +497,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod.write('import pkg\nprint(pkg.a_var)\n')
         self._rename(init_dot_py,
                      init_dot_py.read().index('a_var') + 1, 'new_var')
-        self.assertEquals('new_var = 10\n', init_dot_py.read())
-        self.assertEquals('import pkg\nprint(pkg.new_var)\n', mod.read())
+        self.assertEqual('new_var = 10\n', init_dot_py.read())
+        self.assertEqual('import pkg\nprint(pkg.new_var)\n', mod.read())
 
     def test_renaming_variables_in_init_dot_pys3(self):
         pkg = testutils.create_package(self.project, 'pkg')
@@ -437,8 +507,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('import pkg\nprint(pkg.a_var)\n')
         self._rename(mod, mod.read().index('a_var') + 1, 'new_var')
-        self.assertEquals('new_var = 10\n', init_dot_py.read())
-        self.assertEquals('import pkg\nprint(pkg.new_var)\n', mod.read())
+        self.assertEqual('new_var = 10\n', init_dot_py.read())
+        self.assertEqual('import pkg\nprint(pkg.new_var)\n', mod.read())
 
     def test_renaming_resources_using_rename_module_refactoring(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -447,7 +517,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2.write('import mod1\nmy_var = mod1.a_var\n')
         renamer = rename.Rename(self.project, mod1)
         renamer.get_changes('newmod').do()
-        self.assertEquals('import newmod\nmy_var = newmod.a_var\n',
+        self.assertEqual('import newmod\nmy_var = newmod.a_var\n',
                           mod2.read())
 
     def test_renam_resources_using_rename_module_refactor_for_packages(self):
@@ -456,7 +526,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write('import pkg\nmy_pkg = pkg')
         renamer = rename.Rename(self.project, pkg)
         renamer.get_changes('newpkg').do()
-        self.assertEquals('import newpkg\nmy_pkg = newpkg', mod1.read())
+        self.assertEqual('import newpkg\nmy_pkg = newpkg', mod1.read())
 
     def test_renam_resources_use_rename_module_refactor_for_init_dot_py(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -464,12 +534,12 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write('import pkg\nmy_pkg = pkg')
         renamer = rename.Rename(self.project, pkg.get_child('__init__.py'))
         renamer.get_changes('newpkg').do()
-        self.assertEquals('import newpkg\nmy_pkg = newpkg', mod1.read())
+        self.assertEqual('import newpkg\nmy_pkg = newpkg', mod1.read())
 
     def test_renaming_global_variables(self):
         code = 'a_var = 1\ndef a_func():\n    global a_var\n    var = a_var\n'
         refactored = self._local_rename(code, code.index('a_var'), 'new_var')
-        self.assertEquals(
+        self.assertEqual(
             'new_var = 1\ndef a_func():\n    '
             'global new_var\n    var = new_var\n',
             refactored)
@@ -477,7 +547,7 @@ class RenameRefactoringTest(unittest.TestCase):
     def test_renaming_global_variables2(self):
         code = 'a_var = 1\ndef a_func():\n    global a_var\n    var = a_var\n'
         refactored = self._local_rename(code, code.rindex('a_var'), 'new_var')
-        self.assertEquals(
+        self.assertEqual(
             'new_var = 1\ndef a_func():\n    '
             'global new_var\n    var = new_var\n',
             refactored)
@@ -489,7 +559,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write(code)
         self._rename(mod1, code.index('a_func'),
                      'new_func', unsure=self._true)
-        self.assertEquals(
+        self.assertEqual(
             'class C(object):\n    def new_func(self):\n        pass\n'
             'def f(arg):\n    arg.new_func()\n',
             mod1.read())
@@ -505,7 +575,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write(code)
         self._rename(mod1, code.index('a_func'), 'new_func', unsure=confirm)
-        self.assertEquals(
+        self.assertEqual(
             'class C(object):\n    def new_func(self):\n        pass\n'
             'def f(arg):\n    arg.a_func()\n', mod1.read())
 
@@ -516,7 +586,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write(code)
         self._rename(mod1, code.index('a_func'), 'new_func', unsure=self._true)
-        self.assertEquals(
+        self.assertEqual(
             'class C1(object):\n    def new_func(self):\n        pass\n'
             'class C2(object):\n    def a_func(self):\n        pass\n'
             'c1 = C1()\nc1.new_func()\nc2 = C2()\nc2.a_func()\n',
@@ -527,27 +597,27 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write(code)
         self._rename(mod1, code.index('a_var'), 'new_var', docs=True)
-        self.assertEquals('new_var = 1\n# new_var\n', mod1.read())
+        self.assertEqual('new_var = 1\n# new_var\n', mod1.read())
 
     def test_not_renaming_in_strings_and_comments_where_not_visible(self):
         code = 'def f():\n    a_var = 1\n# a_var\n'
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write(code)
         self._rename(mod1, code.index('a_var'), 'new_var', docs=True)
-        self.assertEquals('def f():\n    new_var = 1\n# a_var\n', mod1.read())
+        self.assertEqual('def f():\n    new_var = 1\n# a_var\n', mod1.read())
 
     def test_not_renaming_all_text_occurrences_in_strings_and_comments(self):
         code = 'a_var = 1\n# a_vard _a_var\n'
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write(code)
         self._rename(mod1, code.index('a_var'), 'new_var', docs=True)
-        self.assertEquals('new_var = 1\n# a_vard _a_var\n', mod1.read())
+        self.assertEqual('new_var = 1\n# a_vard _a_var\n', mod1.read())
 
     def test_renaming_occurrences_in_overwritten_scopes(self):
         refactored = self._local_rename(
             'a_var = 20\ndef f():\n    print(a_var)\n'
             'def f():\n    print(a_var)\n', 2, 'new_var')
-        self.assertEquals('new_var = 20\ndef f():\n    print(new_var)\n'
+        self.assertEqual('new_var = 20\ndef f():\n    print(new_var)\n'
                           'def f():\n    print(new_var)\n', refactored)
 
     def test_renaming_occurrences_in_overwritten_scopes2(self):
@@ -555,13 +625,13 @@ class RenameRefactoringTest(unittest.TestCase):
                'def f():\n    a_var = 1\n    print(a_var)\n'
         refactored = self._local_rename(code, code.index('a_var') + 1,
                                         'new_var')
-        self.assertEquals(code.replace('a_var', 'new_var', 2), refactored)
+        self.assertEqual(code.replace('a_var', 'new_var', 2), refactored)
 
     def test_dos_line_ending_and_renaming(self):
         code = '\r\na = 1\r\n\r\nprint(2 + a + 2)\r\n'
         offset = code.replace('\r\n', '\n').rindex('a')
         refactored = self._local_rename(code, offset, 'b')
-        self.assertEquals('\nb = 1\n\nprint(2 + b + 2)\n',
+        self.assertEqual('\nb = 1\n\nprint(2 + b + 2)\n',
                           refactored.replace('\r\n', '\n'))
 
     def test_multi_byte_strs_and_renaming(self):
@@ -569,7 +639,7 @@ class RenameRefactoringTest(unittest.TestCase):
         code = u'# -*- coding: utf-8 -*-\n# ' + s + \
             '\na = 1\nprint(2 + a + 2)\n'
         refactored = self._local_rename(code, code.rindex('a'), 'b')
-        self.assertEquals(u'# -*- coding: utf-8 -*-\n# ' + s +
+        self.assertEqual(u'# -*- coding: utf-8 -*-\n# ' + s +
                           '\nb = 1\nprint(2 + b + 2)\n', refactored)
 
     def test_resources_parameter(self):
@@ -579,8 +649,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2.write('import mod1\nmod1.f()\n')
         self._rename(mod1, mod1.read().rindex('f'), 'g',
                      resources=[mod1])
-        self.assertEquals('def g():\n    pass\n', mod1.read())
-        self.assertEquals('import mod1\nmod1.f()\n', mod2.read())
+        self.assertEqual('def g():\n    pass\n', mod1.read())
+        self.assertEqual('import mod1\nmod1.f()\n', mod2.read())
 
     def test_resources_parameter_not_changing_defining_module(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -589,8 +659,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2.write('import mod1\nmod1.f()\n')
         self._rename(mod1, mod1.read().rindex('f'), 'g',
                      resources=[mod2])
-        self.assertEquals('def f():\n    pass\n', mod1.read())
-        self.assertEquals('import mod1\nmod1.g()\n', mod2.read())
+        self.assertEqual('def f():\n    pass\n', mod1.read())
+        self.assertEqual('import mod1\nmod1.g()\n', mod2.read())
 
     # XXX: with variables should not leak
     @testutils.only_for('2.5')
@@ -602,7 +672,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write(code)
         self._rename(mod1, code.rindex('f'), 'file')
         expected = 'f = 1\nwith open("1.txt") as file:\n    print(file)\n'
-        self.assertEquals(expected, mod1.read())
+        self.assertEqual(expected, mod1.read())
 
 
 class ChangeOccurrencesTest(unittest.TestCase):
@@ -620,14 +690,14 @@ class ChangeOccurrencesTest(unittest.TestCase):
         changer = rename.ChangeOccurrences(self.project, self.mod,
                                            self.mod.read().index('a_var'))
         changer.get_changes('new_var').do()
-        self.assertEquals('new_var = 1\nprint(new_var)\n', self.mod.read())
+        self.assertEqual('new_var = 1\nprint(new_var)\n', self.mod.read())
 
     def test_only_performing_inside_scopes(self):
         self.mod.write('a_var = 1\nnew_var = 2\ndef f():\n    print(a_var)\n')
         changer = rename.ChangeOccurrences(self.project, self.mod,
                                            self.mod.read().rindex('a_var'))
         changer.get_changes('new_var').do()
-        self.assertEquals(
+        self.assertEqual(
             'a_var = 1\nnew_var = 2\ndef f():\n    print(new_var)\n',
             self.mod.read())
 
@@ -637,7 +707,7 @@ class ChangeOccurrencesTest(unittest.TestCase):
         changer = rename.ChangeOccurrences(self.project, self.mod,
                                            self.mod.read().rindex('f1'))
         changer.get_changes('f2', only_calls=True).do()
-        self.assertEquals(
+        self.assertEqual(
             'def f1():\n    pass\ndef f2():\n    pass\ng = f1\na = f2()\n',
             self.mod.read())
 
@@ -646,7 +716,7 @@ class ChangeOccurrencesTest(unittest.TestCase):
         changer = rename.ChangeOccurrences(self.project, self.mod,
                                            self.mod.read().rindex('a'))
         changer.get_changes('b', writes=False).do()
-        self.assertEquals('a = 1\nb = 2\nprint(b)\n', self.mod.read())
+        self.assertEqual('a = 1\nb = 2\nprint(b)\n', self.mod.read())
 
 
 class ImplicitInterfacesTest(unittest.TestCase):
@@ -675,8 +745,8 @@ class ImplicitInterfacesTest(unittest.TestCase):
                         'mod1.f(A())\nmod1.f(B())\n')
         self.pycore.analyze_module(self.mod2)
         self._rename(self.mod1, self.mod1.read().index('run'), 'newrun')
-        self.assertEquals('def f(arg):\n    arg.newrun()\n', self.mod1.read())
-        self.assertEquals(
+        self.assertEqual('def f(arg):\n    arg.newrun()\n', self.mod1.read())
+        self.assertEqual(
             'import mod1\n\n\n'
             'class A(object):\n    def newrun(self):\n        pass\n'
             'class B(object):\n    def newrun(self):\n        pass\n'
